@@ -85,9 +85,8 @@ def train_gv(gv, targ, esm, cfg, save_params=True, **kwargs):
             kwargs["sel_crit"] = "bic"
         params_gv = train_gv_AR(params_gv, gv, kwargs["max_lag"], kwargs["sel_crit"])
     else:
-        raise ValueError(
-            "The chosen method and / or weighting approach is currently not implemented."
-        )
+        msg = "The chosen method and / or weighting approach is currently not implemented."
+        raise ValueError(msg)
 
     # save the global variability paramters if requested
     if save_params:
@@ -156,7 +155,7 @@ def train_gv_AR(params_gv, gv, max_lag, sel_crit):
     -----
     - Assumptions
         - number of runs per scenario and the number of time steps in each scenario can
-        vary
+          vary
         - each scenario receives equal weight during training
 
     """
